/*
 ============================================================================
 Name        : i2c-relay.c
 Author      : Benjamin Nyffenegger
 Version     :
 Copyright   : University of Bern
 Description : Hello World in C, Ansi-style
 ============================================================================
 */

#include <stdio.h>
#include <string.h>
#include <sys/ioctl.h>
#include <stdlib.h>
#include <fcntl.h>
#include <errno.h>
#include "i2c-dev.hh"

static void help(void) {
	fprintf(stderr,
		"Usage: i2c-relay [-n I2CBUS] [-a|-b on|off]\n"
		"  ex: i2c-relay -n 0 -a on\n");
}

static __u8 getRelayAction(int flags, char *argv[]) {
	if (strcmp(argv[flags+2],"on")==0) {
		return 0x01; //value for turning relay on
	}
	else if (strcmp(argv[flags+2],"off")==0) {
		return 0x00; //value for turning relay off
	}
	else {
		help();
		exit(1);
	}
}

static int getI2CBus(int flags, char *argv[]) {
	return atoi(argv[flags+2]); //number of I2C adapter
}

int main(int argc, char *argv[]) {
	int file;
	int flags = 0;
	int adapter = 0; //default i2c-0
	char i2cbus[20];
	int addr = 0x62 >> 1;
	__u8 cmd = 0x01; //default relay A
	__u8 val = 0x00;

	if (argc < 5) {
		help();
		exit(1);
	}

	while (1 + flags < argc) {
		if (argv[1 + flags][0] == '-') {
			switch (argv[1 + flags][1]) {
			case 'a':
				cmd = 0x01; //choose relay A
				val = getRelayAction(flags, argv);
				printf("Relay: A\nAction: %d\n", val);
				break;
			case 'b':
				cmd = 0x02; //choose relay B
				val = getRelayAction(flags, argv);
				printf("Relay B\nAction: %d\n", val);
				break;
			case 'n':
				adapter = getI2CBus(flags, argv);
				snprintf(i2cbus, 19, "/dev/i2c-%d", adapter);
				printf("I2CBus: %s\n", i2cbus);
				break;
			default:
				fprintf(stderr, "Error: Unsupported option "
					"\"%s\"!\n", argv[1 + flags]);
				help();
				exit(1);
			}
		}
		flags++;
	}


//	if (argc < flags + 2) {
//		fprintf(stderr, "Error: No action specified!\n");
//		help();
//		exit(1);
//	}
//
//	if (strcmp(argv[flags+1],"on")==0) val = 0x01; //value for turning on
//	else if (strcmp(argv[flags+1],"off")==0) val = 0x00; //value for turning off
//	else {
//		help();
//		exit(1);
//	}

	if ((file = open(i2cbus, I2C_SMBUS)) < 0) {
		printf("Cannot open adapter\n");
		exit (1);
	}

	if (ioctl(file, I2C_SLAVE, addr) < 0) {
		printf("ioctl does not work\n");
		exit(1);
	}

	i2c_smbus_write_byte_data (file, cmd, val);
}
